/*
 * Copyright (C) 2018 Boudewijn Rempt <boud@valdyas.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "LibKisUtils.h"

#include <kis_node.h>
#include <kis_paint_layer.h>
#include <kis_group_layer.h>
#include <kis_file_layer.h>
#include <kis_adjustment_layer.h>
#include <kis_generator_layer.h>
#include <kis_clone_layer.h>
#include <kis_shape_layer.h>
#include <kis_transparency_mask.h>
#include <kis_filter_mask.h>
#include <kis_transform_mask.h>
#include <kis_selection_mask.h>
#include <lazybrush/kis_colorize_mask.h>
#include <kis_layer.h>

#include "Node.h"
#include "GroupLayer.h"
#include "CloneLayer.h"
#include "FilterLayer.h"
#include "FillLayer.h"
#include "FileLayer.h"
#include "VectorLayer.h"
#include "FilterMask.h"
#include "SelectionMask.h"

QList<Node *> LibKisUtils::createNodeList(KisNodeList kisnodes, KisImageWSP image)
{
    QList <Node*> nodes;
    Q_FOREACH(KisNodeSP node, kisnodes) {
        if (node->inherits("KisGroupLayer")) {
            nodes << new GroupLayer(dynamic_cast<KisGroupLayer*>(node.data()));
        }
        else if (node->inherits("KisCloneLayer")) {
            nodes << new CloneLayer(dynamic_cast<KisCloneLayer*>(node.data()));
        }
        else if (node->inherits("KisFileLayer")) {
            nodes << new FileLayer(dynamic_cast<KisFileLayer*>(node.data()));
        }
        else if (node->inherits("KisAdjustmentLayer")) {
            nodes << new FilterLayer(dynamic_cast<KisAdjustmentLayer*>(node.data()));
        }
        else if (node->inherits("KisGeneratorLayer")) {
            nodes << new FillLayer(dynamic_cast<KisGeneratorLayer*>(node.data()));
        }
        else if (node->inherits("KisShapeLayer")) {
            nodes << new VectorLayer(dynamic_cast<KisShapeLayer*>(node.data()));
        }
        else if (node->inherits("KisFilterMask")) {
            nodes << new FilterMask(image, dynamic_cast<KisFilterMask*>(node.data()));
        }
        else if (node->inherits("KisSelectionMask")) {
            nodes << new SelectionMask(image, dynamic_cast<KisSelectionMask*>(node.data()));
        }
        else {
            nodes << new Node(image, node);
        }

    }
    return nodes;
}
